.. _using-index:

###################
Working with BigJob
###################


This part of the documentation is devoted to general information on the setup
and configuration of SAGA and things that make working with SAGA easier.


Explain different usage modes, etc...

.. toctree::
   :numbered:

   appwriting.rst
   cmdtools.rst
   logging.rst
